==> hildon-libs_0.9.53-1.tar.gz: hildon-libs-0.9.53/hildon-widgets/hildon-seekbar.h <==
/*
 * This file is part of hildon-libs
 *
 * Copyright (C) 2005 Nokia Corporation.
 *
 * Contact: Luc Pionchon <luc.pionchon@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef __HILDON_SEEKBAR_H__
#define __HILDON_SEEKBAR_H__

#include <gtk/gtkscale.h>

G_BEGIN_DECLS
#define HILDON_TYPE_SEEKBAR ( hildon_seekbar_get_type() )
#define HILDON_SEEKBAR(obj) (GTK_CHECK_CAST (obj,\
        HILDON_TYPE_SEEKBAR, HildonSeekbar))
#define HILDON_SEEKBAR_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass),\
        HILDON_TYPE_SEEKBAR, HildonSeekbarClass))
#define HILDON_IS_SEEKBAR(obj) (GTK_CHECK_TYPE (obj, HILDON_TYPE_SEEKBAR))
#define HILDON_IS_SEEKBAR_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass),\
        HILDON_TYPE_SEEKBAR))
/** 
 * HildonSeekbar:
 * 
 * Contains only private data.
 */
typedef struct _HildonSeekbar HildonSeekbar;
typedef struct _HildonSeekbarClass HildonSeekbarClass;

struct _HildonSeekbar {
    GtkScale scale;
};

struct _HildonSeekbarClass {
    GtkScaleClass parent_class;
};

GType hildon_seekbar_get_type(void);
GtkWidget *hildon_seekbar_new(void);
gint hildon_seekbar_get_total_time(HildonSeekbar *seekbar);
void hildon_seekbar_set_total_time(HildonSeekbar *seekbar, gint time);
gint hildon_seekbar_get_position(HildonSeekbar *seekbar);
void hildon_seekbar_set_position(HildonSeekbar *seekbar, gint time);
void hildon_seekbar_set_fraction(HildonSeekbar *seekbar, guint fraction);
guint hildon_seekbar_get_fraction(HildonSeekbar *seekbar);

G_END_DECLS
#endif

==> hildon-libs_0.12.22-1.tar.gz: hildon-libs-0.12.22/hildon-widgets/hildon-seekbar.h <==
/*
 * This file is part of hildon-libs
 *
 * Copyright (C) 2005 Nokia Corporation.
 *
 * Contact: Luc Pionchon <luc.pionchon@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef __HILDON_SEEKBAR_H__
#define __HILDON_SEEKBAR_H__

#include <gtk/gtkscale.h>

G_BEGIN_DECLS
#define HILDON_TYPE_SEEKBAR ( hildon_seekbar_get_type() )
#define HILDON_SEEKBAR(obj) (GTK_CHECK_CAST (obj,\
        HILDON_TYPE_SEEKBAR, HildonSeekbar))
#define HILDON_SEEKBAR_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass),\
        HILDON_TYPE_SEEKBAR, HildonSeekbarClass))
#define HILDON_IS_SEEKBAR(obj) (GTK_CHECK_TYPE (obj, HILDON_TYPE_SEEKBAR))
#define HILDON_IS_SEEKBAR_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass),\
        HILDON_TYPE_SEEKBAR))
/** 
 * HildonSeekbar:
 * 
 * Contains only private data.
 */
typedef struct _HildonSeekbar HildonSeekbar;
typedef struct _HildonSeekbarClass HildonSeekbarClass;

struct _HildonSeekbar {
    GtkScale scale;
};

struct _HildonSeekbarClass {
    GtkScaleClass parent_class;
};

GType hildon_seekbar_get_type(void) G_GNUC_CONST;
GtkWidget *hildon_seekbar_new(void);
gint hildon_seekbar_get_total_time(HildonSeekbar *seekbar);
void hildon_seekbar_set_total_time(HildonSeekbar *seekbar, gint time);
gint hildon_seekbar_get_position(HildonSeekbar *seekbar);
void hildon_seekbar_set_position(HildonSeekbar *seekbar, gint time);
void hildon_seekbar_set_fraction(HildonSeekbar *seekbar, guint fraction);
guint hildon_seekbar_get_fraction(HildonSeekbar *seekbar);

G_END_DECLS
#endif
